/*
 * libvirt-domain-backup.h
 * Summary: APIs for management of domain backups
 * Description: Provides APIs for the management of domain backups
 *
 * Copyright (C) 2017 Parallels International GmbH
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

#ifndef LIBVIRT_DOMAIN_BACKUP_H
# define LIBVIRT_DOMAIN_BACKUP_H

# ifndef __VIR_LIBVIRT_H_INCLUDES__
#  error "Don't include this file directly, only use libvirt/libvirt.h"
# endif

/**
 * virDomainBlockSnapshotX:
 *
 * Since: vz-8.0.0
 */
typedef struct _virDomainBlockSnapshotX virDomainBlockSnapshotX;

/**
 * virDomainBlockSnapshotXPtr:
 *
 * Since: vz-8.0.0
 */
typedef virDomainBlockSnapshotX *virDomainBlockSnapshotXPtr;

const char *virDomainBlockSnapshotXGetName(virDomainBlockSnapshotXPtr snapshot);
virDomainPtr virDomainBlockSnapshotXGetDomain(virDomainBlockSnapshotXPtr snapshot);
virConnectPtr virDomainBlockSnapshotXGetConnect(virDomainBlockSnapshotXPtr snapshot);

/**
 * virDomainBlockSnapshotXCreateFlags:
 *
 * Since: vz-8.0.0
 */
typedef enum {
    VIR_DOMAIN_BLOCK_SNAPSHOT_X_CREATE_QUIESCE    = (1 << 0), /* use guest agent to
                                                                 quiesce all mounted
                                                                 file systems within the domain
                                                                 (Since: vz-8.0.0) */
    VIR_DOMAIN_BLOCK_SNAPSHOT_X_CREATE_AUTODELETE = (1 << 1), /* TODO (Since: vz-8.0.0)*/
    VIR_DOMAIN_BLOCK_SNAPSHOT_X_CREATE_CHECKPOINT = (1 << 2), /* TODO (Since: vz-8.0.0) */
    VIR_DOMAIN_BLOCK_SNAPSHOT_X_CREATE_BYPASS_CACHE = (1 << 3), /* TODO (Since: vz-8.0.0) */
} virDomainBlockSnapshotXCreateFlags;

virDomainBlockSnapshotXPtr
virDomainBlockSnapshotXCreateXML(virDomainPtr domain,
                                 const char *xmlDesc,
                                 unsigned int flags);

int
virDomainBlockSnapshotXDelete(virDomainBlockSnapshotXPtr snapshot,
                              unsigned int flags);

int
virDomainBlockSnapshotXList(virDomainPtr domain,
                            virDomainBlockSnapshotXPtr **snaps,
                            unsigned int flags);

char*
virDomainBlockSnapshotXGetXMLDesc(virDomainBlockSnapshotXPtr snapshot,
                                  unsigned int flags);

virDomainBlockSnapshotXPtr
virDomainBlockSnapshotXLookupByName(virDomainPtr domain,
                                    const char *name,
                                    unsigned int flags);

int virDomainBlockSnapshotXRef(virDomainBlockSnapshotXPtr snapshot);
int virDomainBlockSnapshotXFree(virDomainBlockSnapshotXPtr snapshot);

/**
 * virDomainBlockCheckpointXRemove:
 *
 * Since: vz-8.0.0
 */
int
virDomainBlockCheckpointXRemove(virDomainPtr domain,
                                const char *name,
                                unsigned int flags);

int
virDomainBlockExportXStart(virDomainPtr domain,
                           const char *xmlDesc,
                           unsigned int flags);

int
virDomainBlockExportXStop(virDomainPtr domain,
                          const char *xmlDesc,
                          unsigned int flags);

#endif /* LIBVIRT_DOMAIN_BACKUP_H */
